@@ -1,28 +1,31 @@
 import json
+import logging
 import os
 import sys
-import logging
 
 import click
 from click import UsageError
 
 import mlflow.db
-import mlflow.experiments
 import mlflow.deployments.cli
+import mlflow.experiments
 import mlflow.projects as projects
 import mlflow.runs
 import mlflow.store.artifact.cli
 from mlflow import tracking
-from mlflow.store.tracking import DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH, DEFAULT_ARTIFACTS_URI
+from mlflow.entities.lifecycle_stage import LifecycleStage
+from mlflow.exceptions import MlflowException
 from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
+from mlflow.store.tracking import (
+    DEFAULT_ARTIFACTS_URI,
+    DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH,
+)
 from mlflow.tracking import _get_store
 from mlflow.utils import cli_args
 from mlflow.utils.annotations import experimental
 from mlflow.utils.logging_utils import eprint
 from mlflow.utils.process import ShellCommandException
 from mlflow.utils.uri import resolve_default_artifact_root
-from mlflow.entities.lifecycle_stage import LifecycleStage
-from mlflow.exceptions import MlflowException
 
 _logger = logging.getLogger(__name__)
 
@@ -264,7 +267,7 @@ def ui(
     address).
     """
     from mlflow.server import _run_server
-    from mlflow.server.handlers import initialize_backend_stores
+    from mlflow.server.stores import initialize_backend_stores
 
     # Ensure that both backend_store_uri and default_artifact_uri are set correctly.
     if not backend_store_uri:
@@ -395,7 +398,7 @@ def server(
     (or a specific interface address).
     """
     from mlflow.server import _run_server
-    from mlflow.server.handlers import initialize_backend_stores
+    from mlflow.server.stores import initialize_backend_stores
 
     _validate_server_args(gunicorn_opts=gunicorn_opts, workers=workers, waitress_opts=waitress_opts)
 
@@ -459,7 +462,7 @@ def gc(backend_store_uri, run_ids):
     This command deletes all artifacts and metadata associated with the specified runs.
     """
     backend_store = _get_store(backend_store_uri, None)
-    if not hasattr(backend_store, "_hard_delete_run"):
+    if not hasattr(backend_store, "hard_delete_run"):
         raise MlflowException(
             "This cli can only be used with a backend that allows hard-deleting runs"
         )
@@ -477,7 +480,7 @@ def gc(backend_store_uri, run_ids):
             )
         artifact_repo = get_artifact_repository(run.info.artifact_uri)
         artifact_repo.delete_artifacts()
-        backend_store._hard_delete_run(run_id)
+        backend_store.hard_delete_run(run_id)
         print("Run with ID %s has been permanently deleted." % str(run_id))
 
 
@@ -489,8 +492,8 @@ cli.add_command(mlflow.db.commands)
 
 try:
     # pylint: disable=unused-import
-    import mlflow.models.cli
     import mlflow.azureml.cli
+    import mlflow.models.cli
     import mlflow.sagemaker.cli
 
     cli.add_command(mlflow.azureml.cli.commands)
