@@ -25,4 +25,12 @@ def upgrade(url):
     import mlflow.store.db.utils
 
     engine = mlflow.store.db.utils.create_sqlalchemy_engine_with_retry(url)
-    mlflow.store.db.utils._upgrade_db(engine)
+
+    # The alembic migrations do not work on a fresh database
+    # Some tables are brought up using in the tracking sqlalchemy
+    # store using _initialize_tables function. _initialize_tables,
+    # creates those tables and calls _upgrade_db (alembic migration) after that.
+    # Here, I am calling _initialize_tables directly for now.
+
+    # mlflow.store.db.utils._upgrade_db(engine)
+    mlflow.store.db.utils._initialize_tables(engine)
