@@ -27,3 +27,12 @@ class Role(enum.IntEnum):
     READ = 1
     WRITE = 3
     ADMIN = 7
+
+@enum.unique
+class PrivacyType(enum.Enum):
+    PUBLIC = "PUBLIC"
+    PRIVATE = "PRIVATE"
+
+    @classmethod
+    def _missing_(cls, value):
+        raise MlflowException(f"Unknown Privacy Type: {value}", error_code=BAD_REQUEST)
