@@ -8,10 +8,12 @@ from mimetypes import guess_type
 from mlflow import data
 from mlflow.entities import FileInfo
 from mlflow.exceptions import MlflowException
+from mlflow.protos.databricks_pb2 import PERMISSION_DENIED
 from mlflow.store.artifact.artifact_repo import ArtifactRepository
 from mlflow.utils.file_utils import relative_path_to_artifact_path
 
 _MAX_CACHE_SECONDS = 300
+_PRESIGNED_URL_EXPIRY_TIME = 1800
 
 
 def _get_utcnow_timestamp():
@@ -82,6 +84,9 @@ class S3ArtifactRepository(ArtifactRepository):
 
     def _get_s3_client(self):
         s3_endpoint_url = os.environ.get("MLFLOW_S3_ENDPOINT_URL")
+        if s3_endpoint_url is not None and not s3_endpoint_url.strip():
+            # hack to handle empty environment variable >:|
+            s3_endpoint_url = None
         ignore_tls = os.environ.get("MLFLOW_S3_IGNORE_TLS")
 
         do_verify = True
@@ -149,7 +154,7 @@ class S3ArtifactRepository(ArtifactRepository):
         if path:
             dest_path = posixpath.join(dest_path, path)
         infos = []
-        prefix = dest_path + "/" if dest_path else ""
+        prefix = (dest_path.rstrip("/") + "/") if dest_path else ""
         s3_client = self._get_s3_client()
         paginator = s3_client.get_paginator("list_objects_v2")
         results = paginator.paginate(Bucket=bucket, Prefix=prefix, Delimiter="/")
@@ -172,7 +177,12 @@ class S3ArtifactRepository(ArtifactRepository):
                 )
                 file_rel_path = posixpath.relpath(path=file_path, start=artifact_path)
                 file_size = int(obj.get("Size"))
-                infos.append(FileInfo(file_rel_path, False, file_size))
+                signed_url = s3_client.generate_presigned_url(
+                    "get_object",
+                    Params={"Bucket": bucket, "Key": file_path},
+                    ExpiresIn=_PRESIGNED_URL_EXPIRY_TIME,
+                )
+                infos.append(FileInfo(file_rel_path, False, file_size, signed_url=signed_url))
         return sorted(infos, key=lambda f: f.path)
 
     @staticmethod
@@ -206,13 +216,38 @@ class S3ArtifactRepository(ArtifactRepository):
             )
             s3_client.delete_object(Bucket=bucket, Key=file_path)
 
-    def get_read_signed_uri(self, artifact_path: str, expires_in: int = 1800) -> str:
+    def _strip_artifact_uri(self, artifact_path: str):
+        if artifact_path.startswith("s3://"):
+            if artifact_path.startswith(self.artifact_uri):
+                artifact_path = artifact_path[len(self.artifact_uri) :]
+            else:
+                raise MlflowException(
+                    f"Not authorized to access the uri: {artifact_path}",
+                    error_code=PERMISSION_DENIED,
+                )
+        return artifact_path.lstrip("/")
+
+    def _get_signed_uri(
+        self, operation_name: str, artifact_path: str, expires_in: int = 1800
+    ) -> str:
         if not artifact_path:
-            raise MlflowException("artifact_path must be notn empty string")
+            raise MlflowException("artifact_path must be not an empty string")
+        # TODO: this is needed till client prepends artifact_uri
+        artifact_path = self._strip_artifact_uri(artifact_path=artifact_path)
         (bucket, s3_root_path) = data.parse_s3_uri(self.artifact_uri)
         s3_client = self._get_s3_client()
         key = posixpath.join(s3_root_path, artifact_path)
 
         return s3_client.generate_presigned_url(
-            "get_object", Params={"Bucket": bucket, "Key": key}, ExpiresIn=expires_in
+            operation_name, Params={"Bucket": bucket, "Key": key}, ExpiresIn=expires_in
+        )
+
+    def get_read_signed_uri(self, artifact_path: str, expires_in: int = 1800) -> str:
+        return self._get_signed_uri(
+            operation_name="get_object", artifact_path=artifact_path, expires_in=expires_in
+        )
+
+    def get_write_signed_uri(self, artifact_path: str, expires_in: int = 1800) -> str:
+        return self._get_signed_uri(
+            operation_name="put_object", artifact_path=artifact_path, expires_in=expires_in
         )
