@@ -291,6 +291,7 @@ class FileStore(AbstractStore):
         # tags are added to the file system and are not written to this dict on write
         # As such, we should not include them in the meta file.
         del experiment_dict["tags"]
+        experiment_dict["privacy_type"] = experiment_dict["privacy_type"].value
         write_yaml(meta_dir, FileStore.META_DATA_FILE_NAME, experiment_dict)
         if tags is not None:
             for tag in tags:
@@ -432,7 +433,7 @@ class FileStore(AbstractStore):
         new_info = run_info._copy_with_overrides(lifecycle_stage=LifecycleStage.DELETED)
         self._overwrite_run_info(new_info)
 
-    def _hard_delete_run(self, run_id):
+    def hard_delete_run(self, run_id):
         """
         Permanently delete a run (metadata and metrics, tags, parameters).
         This is used by the ``mlflow gc`` command line and is not intended to be used elsewhere.
