@@ -7,22 +7,35 @@ exposed in the :py:mod:`mlflow.tracking` module.
 import os
 import time
 import typing
+import uuid
 from collections import OrderedDict
 
 from mlflow.entities import (
+    SENTINEL,
+    Artifact,
+    ArtifactType,
+    ArtifactVersion,
+    CustomMetric,
     ExperimentTag,
+    Feature,
+    FileInfo,
     Metric,
+    Model,
+    ModelSchema,
+    ModelVersion,
     Param,
     Run,
     RunLog,
     RunStatus,
     RunTag,
+    SignedURL,
     ViewType,
 )
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, ErrorCode
 from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
+from mlflow.store.tracking.abstract_store import AbstractStore
 from mlflow.tracking._tracking_service import utils
 from mlflow.utils.mlflow_tags import MLFLOW_USER
 from mlflow.utils.string_utils import is_string_type
@@ -38,6 +51,8 @@ from mlflow.utils.validation import (
     _validate_tag_name,
 )
 
+TrackingStore = typing.TypeVar("TrackingStore", bound=AbstractStore)
+
 
 class TrackingServiceClient:
     """
@@ -58,7 +73,7 @@ class TrackingServiceClient:
         self.store
 
     @property
-    def store(self):
+    def store(self) -> TrackingStore:
         return utils._get_store(self.tracking_uri)
 
     def get_run(self, run_id):
@@ -429,6 +444,12 @@ class TrackingServiceClient:
         """
         self.store.delete_run(run_id)
 
+    def hard_delete_run(self, run_id):
+        """
+        Hard delete a run along with its artifacts, metrics, params and tags.
+        """
+        self.store.hard_delete_run(run_id)
+
     def restore_run(self, run_id):
         """
         Restores a deleted run with the given ID.
@@ -491,3 +512,139 @@ class TrackingServiceClient:
 
     def get_run_by_fqn(self, fqn: str) -> Run:
         return self.store.get_run_by_fqn(fqn=fqn)
+
+    # Mlfoundry Artifacts methods
+    # TODO (chiragjn): consider moving these to another mlfoundry_artifacts_service/client.py
+    # TODO (chiragjn): implement list apis for artifacts and models
+
+    def create_artifact_version(
+        self,
+        experiment_id: typing.Union[int, str],
+        artifact_type: ArtifactType,
+        name: str,
+    ) -> uuid.UUID:
+        return self.store.create_artifact_version(
+            experiment_id=experiment_id, artifact_type=artifact_type, name=name
+        )
+
+    def get_artifact_by_id(self, artifact_id: uuid.UUID) -> Artifact:
+        return self.store.get_artifact_by_id(artifact_id=artifact_id)
+
+    def get_artifact_by_fqn(self, fqn: str) -> Artifact:
+        return self.store.get_artifact_by_fqn(fqn=fqn)
+
+    def notify_failure_for_artifact_version(self, version_id: uuid.UUID):
+        return self.store.notify_failure_for_artifact_version(version_id=version_id)
+
+    def list_files_for_artifact_version(
+        self, version_id: uuid.UUID, path: typing.Optional[str] = None
+    ) -> typing.List[FileInfo]:
+        return self.store.list_files_for_artifact_version(version_id=version_id, path=path)
+
+    def get_signed_urls_for_artifact_version_read(
+        self, version_id: uuid.UUID, paths: typing.List[str]
+    ) -> typing.List[SignedURL]:
+        return self.store.get_signed_urls_for_artifact_version_read(
+            version_id=version_id, paths=paths
+        )
+
+    def get_signed_urls_for_artifact_version_write(
+        self, version_id: uuid.UUID, paths: typing.List[str]
+    ) -> typing.List[SignedURL]:
+        return self.store.get_signed_urls_for_artifact_version_write(
+            version_id=version_id, paths=paths
+        )
+
+    def finalize_artifact_version(
+        self,
+        version_id: uuid.UUID,
+        run_uuid: str,
+        description: typing.Optional[str] = None,
+        # this is only `Optional` because argument default should be {}
+        artifact_metadata: typing.Optional[typing.Dict[str, typing.Any]] = None,
+        data_path: typing.Optional[str] = None,
+        step: typing.Optional[int] = None,
+    ) -> ArtifactVersion:
+        return self.store.finalize_artifact_version(
+            version_id=version_id,
+            run_uuid=run_uuid,
+            description=description,
+            artifact_metadata=artifact_metadata,
+            data_path=data_path,
+            step=step,
+        )
+
+    def get_artifact_version_by_id(self, version_id: uuid.UUID) -> ArtifactVersion:
+        return self.store.get_artifact_version_by_id(version_id=version_id)
+
+    def get_artifact_version_by_fqn(self, fqn: str) -> ArtifactVersion:
+        return self.store.get_artifact_version_by_fqn(fqn=fqn)
+
+    def update_artifact_version(
+        self,
+        version_id: uuid.UUID,
+        description: typing.Optional[str] = SENTINEL,
+        artifact_metadata: typing.Dict[str, typing.Any] = SENTINEL,
+    ) -> ArtifactVersion:
+        return self.store.update_artifact_version(
+            version_id=version_id, description=description, artifact_metadata=artifact_metadata
+        )
+
+    def delete_artifact_version(self, version_id: uuid.UUID):
+        return self.store.delete_artifact_version(version_id=version_id)
+
+    def get_model_by_id(self, model_id: uuid.UUID) -> Model:
+        return self.store.get_model_by_id(model_id=model_id)
+
+    def get_model_by_fqn(self, fqn: str) -> Model:
+        return self.store.get_model_by_fqn(fqn=fqn)
+
+    def create_model_version(
+        self,
+        artifact_version_id: uuid.UUID,
+        description: typing.Optional[str] = SENTINEL,
+        artifact_metadata: typing.Dict[str, typing.Any] = SENTINEL,
+        data_path: typing.Optional[str] = SENTINEL,
+        step: typing.Optional[int] = SENTINEL,
+    ) -> ModelVersion:
+        return self.store.create_model_version(
+            artifact_version_id=artifact_version_id,
+            description=description,
+            artifact_metadata=artifact_metadata,
+            data_path=data_path,
+            step=step,
+        )
+
+    def get_model_version_by_id(self, version_id: uuid.UUID) -> ModelVersion:
+        return self.store.get_model_version_by_id(version_id=version_id)
+
+    def get_model_version_by_fqn(self, fqn: str) -> ModelVersion:
+        return self.store.get_model_version_by_fqn(fqn=fqn)
+
+    def update_model_version(
+        self,
+        version_id: uuid.UUID,
+        description: typing.Optional[str] = SENTINEL,
+        artifact_metadata: typing.Dict[str, typing.Any] = SENTINEL,
+        model_schema: ModelSchema = SENTINEL,
+    ) -> ModelVersion:
+        return self.store.update_model_version(
+            version_id=version_id,
+            description=description,
+            artifact_metadata=artifact_metadata,
+            model_schema=model_schema,
+        )
+
+    def add_features_to_model_version(
+        self, version_id: uuid.UUID, features: typing.List[Feature]
+    ) -> ModelVersion:
+        return self.store.add_features_to_model_version(version_id=version_id, features=features)
+
+    def add_custom_metrics_to_model_version(
+        self,
+        version_id: uuid.UUID,
+        custom_metrics: typing.List[CustomMetric],
+    ) -> ModelVersion:
+        return self.store.add_custom_metrics_to_model_version(
+            version_id=version_id, custom_metrics=custom_metrics
+        )
