@@ -4,6 +4,7 @@ import json
 from collections import defaultdict
 from functools import partial
 from json import JSONEncoder
+from typing import Any
 
 from google.protobuf.descriptor import FieldDescriptor
 from google.protobuf.json_format import MessageToJson, ParseDict
@@ -353,3 +354,10 @@ def parse_tf_serving_input(inp_dict, schema=None):
             )
 
     return data
+
+
+def get_field_if_set(request_message, field_name: str, default: Any) -> Any:
+    # Note: HasField returns False even if field is set but with a None value
+    if request_message.HasField(field_name):
+        return getattr(request_message, field_name)
+    return default
